@@ -7,6 +7,35 @@ qingzanggongsi, chengduju, kunmingju, lanzhouju, xianju, taiyuanju, zhengzhouju,
 guangzhouju, nanningju, wuhanju
 
 
+def get_center_coordinate():
+    """
+    根据各路局中心点坐标，组成json数据，用于热力图坐标绘制
+    :return: center_json_data
+    """
+    # 也可以根据需要修改字典中的路局名称以及坐标值
+    center_json_data = {
+        '哈尔滨局': haerbinju['features'][0]['properties']['cp'],
+        '沈阳局': shenyangju['features'][0]['properties']['cp'],
+        '呼和浩特局': huhehaoteju['features'][0]['properties']['cp'],
+        '北京局': beijingju['features'][0]['properties']['cp'],
+        '乌鲁木齐局': wulumuqiju['features'][0]['properties']['cp'],
+        '青藏公司': qingzanggongsi['features'][0]['properties']['cp'],
+        '成都局': chengduju['features'][0]['properties']['cp'],
+        '昆明局': kunmingju['features'][0]['properties']['cp'],
+        '兰州局': lanzhouju['features'][0]['properties']['cp'],
+        '西安局': xianju['features'][0]['properties']['cp'],
+        '太原局': taiyuanju['features'][0]['properties']['cp'],
+        '郑州局': zhengzhouju['features'][0]['properties']['cp'],
+        '济南局': jinanju['features'][0]['properties']['cp'],
+        '上海局': shanghaiju['features'][0]['properties']['cp'],
+        '南昌局': nanchangju['features'][0]['properties']['cp'],
+        '广州局': guangzhouju['features'][0]['properties']['cp'],
+        '南宁局': nanningju['features'][0]['properties']['cp'],
+        '武汉局': wuhanju['features'][0]['properties']['cp']
+    }
+    return center_json_data
+
+
 def blank_map(bureau_data, without_name=True):
     """
     空白显示的地图
@@ -142,7 +171,7 @@ def normal_map(bureau_data):
 def heat_signal_color_map(bureau_data, reduction_factor=5, symbol_color='#ff0000'):
     """
     热力地图-单色
-    :param bureau_data: 路局名称和数据的list
+    :param bureau_data: 路局名称和数据的list [['沈阳局', 100],...]
     :param reduction_factor: 图标根据实际值缩放的大小，默认=5
     :param symbol_color: 图标显示的颜色，默认红色
     :return: 生成html文件，无返回值
@@ -153,24 +182,11 @@ def heat_signal_color_map(bureau_data, reduction_factor=5, symbol_color='#ff0000
     # 用原生JS来计算圆形的尺寸
     get_symbol_size = 'function (val) {return val[2]/' + '{0};'.format(reduction_factor) + '}'
 
-    # 用路局所在地的坐标进行标注
-    center_json_data_file = r'.\railway_bureau_map\center_json_data_city.json'
-
     file_name = 'China_railway_bureau_map(heat_signal_color).html'
     heat_map = (
         Geo(init_opts=opts.InitOpts(width='1000px', height='750px', bg_color='white', page_title='各路局热力地图'))
         .add_js_funcs("echarts.registerMap('china_railway', {});".format(json_data))
         .add_schema(maptype="china_railway")
-        .add_coordinate_json(center_json_data_file)
-        .add(
-            series_name='',
-            data_pair=bureau_data,
-            type_=ChartType.EFFECT_SCATTER,
-            # 尺寸定义
-            symbol_size=JsCode(get_symbol_size),
-            color=symbol_color
-            )
-        .set_series_opts(label_opts=opts.LabelOpts(is_show=False))
         .set_global_opts(
             title_opts=opts.TitleOpts(title='中国各路局设备数量分布热力图'),
             toolbox_opts=opts.ToolboxOpts(
@@ -192,16 +208,33 @@ def heat_signal_color_map(bureau_data, reduction_factor=5, symbol_color='#ff0000
             )
         )
     )
+    # 获取路局中心坐标点
+    center_coordinate_dict = get_center_coordinate()
+    # 增加坐标点
+    for item in bureau_data:
+        if item[0] in center_coordinate_dict:
+            # 当数据的名称是规定的路径名称，数据才会增加到地图上
+            heat_map.add_coordinate(name=item[0],
+                                    longitude=center_coordinate_dict[item[0]][0],
+                                    latitude=center_coordinate_dict[item[0]][1])
+    heat_map.add(
+        series_name='',
+        data_pair=bureau_data,
+        type_=ChartType.EFFECT_SCATTER,
+        # 尺寸定义
+        symbol_size=JsCode(get_symbol_size),
+        color=symbol_color
+    )
+    heat_map.set_series_opts(label_opts=opts.LabelOpts(is_show=True, formatter='{b}'))
     heat_map.render('{0}'.format(file_name))
     print('文件{0}已生成至当前路径下!'.format(file_name))
 
 
-def heat_mult_color_map(bureau_data, display_type='effect', location='p'):
+def heat_mult_color_map(bureau_data, display_type='effect'):
     """
     热力地图-多种颜色
     :param bureau_data: 路局名称和数据的list
     :param display_type: 显示效果EFFECT_SCATTER or HEATMAP
-    :param location: 地理坐标采用路局所在省的坐标还是真实单位地址 p=省的坐标地址
     :return: 生成html文件，无返回值
     """
     json_data = china_railway_bureau_map
@@ -211,14 +244,6 @@ def heat_mult_color_map(bureau_data, display_type='effect', location='p'):
     min_data = min(data_list)
     max_data = max(data_list)
 
-    if location == 'p':
-        # 用省的坐标代表具体的路径
-        center_json_data_file = r'.\railway_bureau_map\center_json_data_province.json'
-    else:
-        # 用路局所在地的坐标进行标注
-        center_json_data_file = r'.\railway_bureau_map\center_json_data_city.json'
-
-    # bureau_data[3][0] = '西宁'
     if display_type == 'effect':
         display_type = ChartType.EFFECT_SCATTER
     else:
@@ -228,16 +253,6 @@ def heat_mult_color_map(bureau_data, display_type='effect', location='p'):
         Geo(init_opts=opts.InitOpts(width='1000px', height='750px', bg_color='white', page_title='各路局热力地图'))
         .add_js_funcs("echarts.registerMap('china_railway', {});".format(json_data))
         .add_schema(maptype="china_railway")
-        .add_coordinate_json(center_json_data_file)
-        .add(
-            series_name='',
-            data_pair=bureau_data,
-            type_=display_type,
-            # 尺寸定义
-            symbol_size=25
-
-            )
-        .set_series_opts(label_opts=opts.LabelOpts(is_show=False))
         .set_global_opts(
             title_opts=opts.TitleOpts(title='中国各路局设备数量分布热力图'),
             visualmap_opts=opts.VisualMapOpts(
@@ -268,6 +283,23 @@ def heat_mult_color_map(bureau_data, display_type='effect', location='p'):
             )
         )
     )
+    # 获取路局中心坐标点
+    center_coordinate_dict = get_center_coordinate()
+    # 增加坐标点
+    for item in bureau_data:
+        if item[0] in center_coordinate_dict:
+            # 当数据的名称是规定的路径名称，数据才会增加到地图上
+            heat_map.add_coordinate(name=item[0],
+                                    longitude=center_coordinate_dict[item[0]][0],
+                                    latitude=center_coordinate_dict[item[0]][1])
+    heat_map.add(
+        series_name='',
+        data_pair=bureau_data,
+        type_=display_type,
+        # 尺寸定义
+        symbol_size=25
+    )
+    heat_map.set_series_opts(label_opts=opts.LabelOpts(is_show=True, formatter='{b}'))
     heat_map.render('{0}'.format(file_name))
     print('文件{0}已生成至当前路径下!'.format(file_name))
 
